@@ -240,26 +240,12 @@ pub fn scanning_radix_sort<T>(
 #[cfg(test)]
 mod tests {
     use crate::sorts::scanning_radix_sort::scanning_radix_sort;
-    use crate::test_utils::sort_comparison_suite;
+    use crate::test_utils::{sort_comparison_suite, NumericTest};
     use crate::tuning_parameters::TuningParameters;
-    use crate::RadixKey;
-    use nanorand::{RandomGen, WyRand};
-    use std::fmt::Debug;
-    use std::ops::{Shl, Shr};
 
     fn test_scanning_sort<T>(shift: T)
     where
-        T: RadixKey
-            + Ord
-            + RandomGen<WyRand>
-            + Clone
-            + Debug
-            + Send
-            + Sized
-            + Copy
-            + Sync
-            + Shl<Output = T>
-            + Shr<Output = T>,
+        T: NumericTest<T>,
     {
         let tuning = TuningParameters::new(T::LEVELS);
         sort_comparison_suite(shift, |inputs| {
